
//   Copyright 2021 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

package com.example.app;

import com.esri.arcgisruntime.ArcGISRuntimeEnvironment;
import com.esri.arcgisruntime.mapping.ArcGISScene;
import com.esri.arcgisruntime.mapping.view.SceneView;
import com.esri.arcgisruntime.portal.Portal;
import com.esri.arcgisruntime.portal.PortalItem;

import javafx.application.Application;
import javafx.scene.Scene;
import javafx.scene.layout.StackPane;
import javafx.stage.Stage;

public class App extends Application {

  private SceneView sceneView;

  public static void main(String[] args) {
    Application.launch(args);
  }

  @Override
  public void start(Stage stage) {

    // set the title and size of the stage and show it
    stage.setTitle("Display a web scene tutorial");

    stage.setWidth(800);
    stage.setHeight(700);
    stage.show();

    // create a JavaFX scene with a stack pane as the root node, and add it to the scene
    StackPane stackPane = new StackPane();
    Scene fxScene = new Scene(stackPane);

    stage.setScene(fxScene);

    // Note: it is not best practice to store API keys in source code.
    // The API key is referenced here for the convenience of this tutorial.
    String yourApiKey = "YOUR_API_KEY";
    ArcGISRuntimeEnvironment.setApiKey(yourApiKey);

    // create a scene view to display the scene and add it to the stack pane
    sceneView = new SceneView();
    stackPane.getChildren().add(sceneView);

    // create a scene from a web scene portal item and set it to the scene view

    Portal portal = new Portal("http://www.arcgis.com/", false);

    PortalItem portalItem = new PortalItem(portal, "579f97b2f3b94d4a8e48a5f140a6639b");

    ArcGISScene scene = new ArcGISScene(portalItem);

    // set the scene on the scene view
    sceneView.setArcGISScene(scene);

  }

  /**
   * Stops and releases all resources used in application.
   */
  @Override
  public void stop() {
    if (sceneView != null) {
      sceneView.dispose();
    }
  }

}


